@@ -43,7 +43,7 @@ class WebSocketTunnelConnection(tornado.websocket.WebSocketClientConnection):
             self._url,
             headers=headers,
             connect_timeout=timeout,
-            request_timeout=timeout,
+            request_timeout=None,
             ca_certs=ca_cert,
             client_key=client_key,
             client_cert=client_cert,
@@ -133,12 +133,17 @@ class WebSocketTunnelConnection(tornado.websocket.WebSocketClientConnection):
             if self._connected == None:
                 await asyncio.sleep(0.005)
                 continue
+            if not self._connected:
+                self.connect_future.cancel()
+                self.close()
             self._patcher.unpatch()
             return self._connected
         else:
             utils.logger.warn(
                 "[%s] Connect %s timeout" % (self.__class__.__name__, self._url)
             )
+            self.final_callback = None
+            self.close()
             self._patcher.unpatch()
             return False
 
@@ -171,9 +176,10 @@ class WebSocketTunnel(tunnel.Tunnel):
         headers = {}
         auth_data = self._url.auth
         if auth_data:
-            headers["Proxy-Authorization"] = "Basic %s" % auth.http_basic_auth(
+            basic_auth = "Basic %s" % auth.http_basic_auth(
                 *auth_data.split(":")
             )
+            headers["X-Proxy-Authorization"] = headers["Proxy-Authorization"] = basic_auth
         ca_cert = self._url.params.pop("ca_cert", None)
         client_key = self._url.params.pop("client_key", None)
         client_cert = self._url.params.pop("client_cert", None)
@@ -265,7 +271,7 @@ class WebSocketTunnelServer(server.TunnelServer):
                 if auth_data:
                     auth_data = auth_data.split(":")
                     for header in self.request.headers:
-                        if header == "Proxy-Authorization":
+                        if header in ("Proxy-Authorization", "X-Proxy-Authorization"):
                             value = self.request.headers[header]
                             auth_type, auth_value = value.split()
                             if (
